pub struct Usbfsh { /* private fields */ }Expand description
USB0 Full-speed Host controller
Implementations
Sourceimpl Usbfsh
impl Usbfsh
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn hcrevision(self) -> Reg<Hcrevision, R>
pub const fn hcrevision(self) -> Reg<Hcrevision, R>
BCD representation of the version of the HCI specification that is implemented by the Host Controller (HC)
Sourcepub const fn hccommandstatus(self) -> Reg<Hccommandstatus, RW>
pub const fn hccommandstatus(self) -> Reg<Hccommandstatus, RW>
This register is used to receive the commands from the Host Controller Driver (HCD)
Sourcepub const fn hcinterruptstatus(self) -> Reg<Hcinterruptstatus, RW>
pub const fn hcinterruptstatus(self) -> Reg<Hcinterruptstatus, RW>
Indicates the status on various events that cause hardware interrupts by setting the appropriate bits
Sourcepub const fn hcinterruptenable(self) -> Reg<Hcinterruptenable, RW>
pub const fn hcinterruptenable(self) -> Reg<Hcinterruptenable, RW>
Controls the bits in the HcInterruptStatus register and indicates which events will generate a hardware interrupt
Sourcepub const fn hcinterruptdisable(self) -> Reg<Hcinterruptdisable, RW>
pub const fn hcinterruptdisable(self) -> Reg<Hcinterruptdisable, RW>
The bits in this register are used to disable corresponding bits in the HCInterruptStatus register and in turn disable that event leading to hardware interrupt
Sourcepub const fn hchcca(self) -> Reg<Hchcca, RW>
pub const fn hchcca(self) -> Reg<Hchcca, RW>
Contains the physical address of the host controller communication area
Sourcepub const fn hcperiodcurrented(self) -> Reg<Hcperiodcurrented, RW>
pub const fn hcperiodcurrented(self) -> Reg<Hcperiodcurrented, RW>
Contains the physical address of the current isochronous or interrupt endpoint descriptor
Sourcepub const fn hccontrolheaded(self) -> Reg<Hccontrolheaded, RW>
pub const fn hccontrolheaded(self) -> Reg<Hccontrolheaded, RW>
Contains the physical address of the first endpoint descriptor of the control list
Sourcepub const fn hccontrolcurrented(self) -> Reg<Hccontrolcurrented, RW>
pub const fn hccontrolcurrented(self) -> Reg<Hccontrolcurrented, RW>
Contains the physical address of the current endpoint descriptor of the control list
Sourcepub const fn hcbulkheaded(self) -> Reg<Hcbulkheaded, RW>
pub const fn hcbulkheaded(self) -> Reg<Hcbulkheaded, RW>
Contains the physical address of the first endpoint descriptor of the bulk list
Sourcepub const fn hcbulkcurrented(self) -> Reg<Hcbulkcurrented, RW>
pub const fn hcbulkcurrented(self) -> Reg<Hcbulkcurrented, RW>
Contains the physical address of the current endpoint descriptor of the bulk list
Sourcepub const fn hcdonehead(self) -> Reg<Hcdonehead, RW>
pub const fn hcdonehead(self) -> Reg<Hcdonehead, RW>
Contains the physical address of the last transfer descriptor added to the ‘Done’ queue
Sourcepub const fn hcfminterval(self) -> Reg<Hcfminterval, RW>
pub const fn hcfminterval(self) -> Reg<Hcfminterval, RW>
Defines the bit time interval in a frame and the full speed maximum packet size which would not cause an overrun
Sourcepub const fn hcfmremaining(self) -> Reg<Hcfmremaining, RW>
pub const fn hcfmremaining(self) -> Reg<Hcfmremaining, RW>
A 14-bit counter showing the bit time remaining in the current frame
Sourcepub const fn hcfmnumber(self) -> Reg<Hcfmnumber, RW>
pub const fn hcfmnumber(self) -> Reg<Hcfmnumber, RW>
Contains a 16-bit counter and provides the timing reference among events happening in the HC and the HCD
Sourcepub const fn hcperiodicstart(self) -> Reg<Hcperiodicstart, RW>
pub const fn hcperiodicstart(self) -> Reg<Hcperiodicstart, RW>
Contains a programmable 14-bit value which determines the earliest time HC should start processing a periodic list
Sourcepub const fn hclsthreshold(self) -> Reg<Hclsthreshold, RW>
pub const fn hclsthreshold(self) -> Reg<Hclsthreshold, RW>
Contains 11-bit value which is used by the HC to determine whether to commit to transfer a maximum of 8-byte LS packet before EOF
Sourcepub const fn hcrhdescriptora(self) -> Reg<Hcrhdescriptora, RW>
pub const fn hcrhdescriptora(self) -> Reg<Hcrhdescriptora, RW>
First of the two registers which describes the characteristics of the root hub
Sourcepub const fn hcrhdescriptorb(self) -> Reg<Hcrhdescriptorb, RW>
pub const fn hcrhdescriptorb(self) -> Reg<Hcrhdescriptorb, RW>
Second of the two registers which describes the characteristics of the Root Hub
Sourcepub const fn hcrhstatus(self) -> Reg<Hcrhstatus, RW>
pub const fn hcrhstatus(self) -> Reg<Hcrhstatus, RW>
This register is divided into two parts
Sourcepub const fn hcrhportstatus(self) -> Reg<Hcrhportstatus, RW>
pub const fn hcrhportstatus(self) -> Reg<Hcrhportstatus, RW>
Controls and reports the port events on a per-port basis